@@ -1,14 +1,18 @@
 #' Morphological analysis for a specific column in dataframe
-#'
+#' 
 #' Using 'MeCab' for morphological analysis.
 #' Keep other colnames in dataframe.
-#'
+#' 
 #' @param tbl          A tibble or data.frame.
 #' @param text_col     A text. Colnames for morphological analysis.
 #' @param bin_dir      A text. Directory of mecab.
 #' @param option       A text. Options for mecab.
 #'                     "-b" option is already set by moranajp.
 #'                     See by "mecab -h".
+#' @param iconv        A text. Convert encoding of MeCab output. 
+#'                     Default (""): don't convert. 
+#'                     "CP932_UTF-8": iconv(output, from = "Shift-JIS" to = "UTF-8")
+#'                     "EUC_UTF-8"  : iconv(output, from = "eucjp", to = "UTF-8")
 #' @return A tibble.   Output of 'MeCab' and added column "text_id".
 #' @examples
 #' \dontrun{
@@ -18,41 +22,50 @@
 #'       neko %>%
 #'       dplyr::mutate(text=stringi::stri_unescape_unicode(text)) %>%
 #'       dplyr::mutate(cols=1:nrow(.))
-#'   moranajp_all(neko, text_col = "text") %>%
+#'   bin_dir <- "d:/pf/mecab/bin"
+#'   moranajp_all(neko, text_col = "text", bin_dir = bin_dir) %>%
 #'       print(n=100)
 #' }
 #' @export
-moranajp_all <- function(tbl, bin_dir, text_col = "text", option = "") {
-    tbl <- dplyr::mutate(tbl, `:=`("text_id", 1:nrow(tbl)))
+moranajp_all <- function(tbl, bin_dir, text_col = "text", option = "", iconv = "CP932_UTF-8") {
+    text_id <- "text_id"
+    tbl <- dplyr::mutate(tbl, `:=`(text_id, 1:nrow(tbl)))
     others <- dplyr::select(tbl, !dplyr::all_of(text_col))
     if (stringr::str_detect(
             stringr::str_c(tbl[[text_col]], collapse = FALSE), "\\r\\n"))
         message("Removed line breaks !")
     if (stringr::str_detect(stringr::str_c(tbl[[text_col]], collapse = FALSE), "\\n"))
         message("Removed line breaks !")
-      # remove line breaks
+    if (stringr::str_detect(stringr::str_c(tbl[[text_col]], collapse = FALSE), '&|\\||<|>|"'))
+        message('Removed &, |, <. > or " !')
+      # remove line breaks and '&||<>"'
     tbl <-
         tbl %>%
-        dplyr::mutate(`:=`(!!text_col,
+        dplyr::mutate(`:=`({{text_col}},
             stringr::str_replace_all(.data[[text_col]], "\\r\\n", ""))) %>%
-        dplyr::mutate(`:=`(!!text_col,
-            stringr::str_replace_all(.data[[text_col]], "\\n", "")))
+        dplyr::mutate(`:=`({{text_col}},
+            stringr::str_replace_all(.data[[text_col]], "\\n", ""))) %>%
+        dplyr::mutate(`:=`({{text_col}},
+            stringr::str_replace_all(.data[[text_col]], '&|\\||<|>|"', "")))
+    group      <- "tmp_group"  # Use temporary
+    str_length <- "str_length" # Use temporary
     tbl <-
         tbl %>%
-        make_groups(text_col = text_col, length = 8000) %>%
-        split(~gr) %>%
+        make_groups(text_col = text_col, length = 8000, 
+            group = group, str_length = str_length) %>%
+        dplyr::group_split(.data[[group]]) %>%
         purrr::map(dplyr::select, dplyr::all_of(text_col)) %>%
-        purrr::map(moranajp, bin_dir = bin_dir, option = option) %>%
+        purrr::map(moranajp, bin_dir = bin_dir, option = option, iconv = iconv) %>%
         dplyr::bind_rows() %>%
         add_text_id() %>%
-        dplyr::left_join(others, by = "text_id") %>%
-        dplyr::relocate(.data[["text_id"]], colnames(others))
+        dplyr::left_join(others, by = text_id) %>%
+        dplyr::relocate(.data[[text_id]], colnames(others))
     return(dplyr::slice(tbl, -nrow(tbl)))
 }
 
 #' @rdname moranajp_all
 #' @export
-moranajp <- function(tbl, bin_dir, option = "") {
+moranajp <- function(tbl, bin_dir, option = "", iconv = "") {
       # Make command
     cmd <- make_cmd_mecab(tbl, bin_dir, option = "")
       # Run
@@ -61,6 +74,11 @@ moranajp <- function(tbl, bin_dir, option = "") {
     } else {
         output <- system(cmd, intern=TRUE)
     }
+      # Convert Encoding
+    if(iconv == "CP932_UTF-8")
+        output <- iconv(output, from = "Shift-JIS", to = "UTF-8")
+    if(iconv == "EUC_UTF-8")
+        output <- iconv(output, from = "eucjp", to = "UTF-8")
       # To tidy data
     out_cols <- out_cols_mecab()
     tbl <-
@@ -133,15 +151,15 @@ add_series_no <- function(tbl, cond = "", end_sep = TRUE, new_col = "series_no")
         stop("colnames must NOT have a colname", new_col)
     tbl <-
         tbl %>%
-        dplyr::mutate(`:=`(!!new_col,
+        dplyr::mutate(`:=`({{new_col}},
             dplyr::case_when(eval(str2expression(cond)) ~ 1, TRUE ~ 0))) %>%
-        dplyr::mutate(`:=`(!!new_col,
+        dplyr::mutate(`:=`({{new_col}},
             purrr::accumulate(.data[[new_col]], magrittr::add)))
     if(end_sep){  # when condition indicate the end of separation
         tbl <-
             tbl %>%
-            dplyr::mutate(`:=`(!!new_col, .data[[new_col]] + 1)) %>%
-            dplyr::mutate(`:=`(!!new_col,
+            dplyr::mutate(`:=`({{new_col}}, .data[[new_col]] + 1)) %>%
+            dplyr::mutate(`:=`({{new_col}},
                 dplyr::lag(.data[[new_col]], default=1)))
     }
    return(tbl)
