@@ -20,7 +20,7 @@ test_that("text_id of moranajp matches text number", {
           neko %>%
           dplyr::mutate(text=stringi::stri_unescape_unicode(text)) %>%
           dplyr::mutate(cols=1:nrow(.)) %>%
-          moranajp_all(text_col="text", bin_dir=bin_dir)
+          moranajp_all(text_col="text", bin_dir=bin_dir, iconv = "CP932_UTF-8")
     }
     skip_if(length(bin_dir) != 1)
         expect_equal(res$cols, res$text_id)
